@@ -21,9 +21,10 @@
 from dateutil.relativedelta import relativedelta
 from datetime import datetime
 from trytond.model import ModelView, ModelSingleton, ModelSQL, fields
+from trytond.wizard import Wizard, StateAction, StateView, Button
 from trytond.transaction import Transaction
 from trytond.backend import TableHandler
-from trytond.pyson import Eval, Not, Bool
+from trytond.pyson import Eval, Not, Bool, PYSONEncoder
 from trytond.pool import Pool
 
 
@@ -34,6 +35,7 @@ __all__ = ['DrugDoseUnits', 'MedicationFrequency', 'DrugForm', 'DrugRoute',
     'Pathology', 'DiseaseMembers', 'ProcedureCode', 'InsurancePlan',
     'Insurance', 'PartyPatient', 'PartyAddress', 'Product',
     'GnuHealthSequences', 'PatientData', 'PatientDiseaseInfo', 'Appointment',
+    'AppointmentReport', 'OpenAppointmentReportStart', 'OpenAppointmentReport',
     'MedicationTemplate', 'PatientMedication', 'PatientVaccination',
     'PatientPrescriptionOrder', 'PrescriptionLine', 'PatientEvaluation',
     'Directions', 'SecondaryCondition', 'DiagnosticHypothesis',
@@ -616,6 +618,8 @@ class Product(ModelSQL, ModelView):
 
     is_medicament = fields.Boolean('Medicament',
         help='Check if the product is a medicament')
+    is_medical_supply = fields.Boolean('Medical Supply',
+        help='Check if the product is a medical supply')
     is_vaccine = fields.Boolean('Vaccine',
         help='Check if the product is a vaccine')
     is_bed = fields.Boolean('Bed',
@@ -731,6 +735,7 @@ class PatientData(ModelSQL, ModelView):
     marital_status = fields.Selection([
         ('s', 'Single'),
         ('m', 'Married'),
+        ('c', 'Concubinage'),
         ('w', 'Widowed'),
         ('d', 'Divorced'),
         ('x', 'Separated'),
@@ -785,6 +790,8 @@ class PatientData(ModelSQL, ModelView):
         depends=['deceased'])
     childbearing_age = fields.Function(fields.Boolean(
             'Potential for Childbearing'), 'patient_age')
+    appointments = fields.One2Many('gnuhealth.appointment', 'patient',
+        'Appointments')
 
     @classmethod
     def __setup__(cls):
@@ -1013,6 +1020,133 @@ class Appointment(ModelSQL, ModelView):
         return self.name
 
 
+class AppointmentReport(ModelSQL, ModelView):
+    'Appointment Report'
+    __name__ = 'gnuhealth.appointment.report'
+
+    identification_code = fields.Char('Identification Code')
+    ref = fields.Char('SSN')
+    patient = fields.Many2One('gnuhealth.patient', 'Patient')
+    doctor = fields.Many2One('gnuhealth.physician', 'Doctor')
+    age = fields.Function(fields.Char('Age'), 'get_patient_age')
+    sex = fields.Selection([('m', 'Male'), ('f', 'Female')], 'Sex')
+    address = fields.Function(fields.Char('Address'), 'get_address')
+    insurance = fields.Function(fields.Char('Insurance'), 'get_insurance')
+    appointment_date = fields.Date('Date')
+    appointment_date_time = fields.DateTime('Date and Time')
+    diagnosis = fields.Function(fields.Many2One('gnuhealth.pathology',
+        'Presumptive Diagnosis'), 'get_diagnosis')
+
+    @classmethod
+    def __setup__(cls):
+        super(AppointmentReport, cls).__setup__()
+        cls._order.insert(0, ('appointment_date_time', 'ASC'))
+
+    @classmethod
+    def table_query(cls):
+        where_clause = ' '
+        args = []
+        if Transaction().context.get('date'):
+            where_clause += "AND a.appointment_date >= %s AND " \
+                "a.appointment_date < %s + integer '1' "
+            args.append(Transaction().context['date'])
+            args.append(Transaction().context['date'])
+        if Transaction().context.get('doctor'):
+            where_clause += 'AND a.doctor = %s '
+            args.append(Transaction().context['doctor'])
+        return ('SELECT id, create_uid, create_date, write_uid, write_date, '
+                    'identification_code, ref, patient, sex, '
+                    'appointment_date, appointment_date_time, doctor '
+                    'FROM ('
+                        'SELECT a.id, a.create_uid, a.create_date, '
+                        'a.write_uid, a.write_date, p.identification_code, '
+                        'r.ref, p.id as patient, p.sex, a.appointment_date, '
+                        'a.appointment_date as appointment_date_time, '
+                        'a.doctor '
+                        'FROM gnuhealth_appointment a, '
+                        'gnuhealth_patient p, party_party r '
+                        'WHERE a.patient = p.id '
+                        + where_clause +
+                        'AND p.name = r.id) AS ' + cls._table, args)
+
+    def get_address(self, name):
+        res = ''
+        if self.patient.name.addresses:
+            res = self.patient.name.addresses[0].full_address
+        return res
+
+    def get_insurance(self, name):
+        res = ''
+        if self.patient.current_insurance:
+            res = self.patient.current_insurance.company.name
+        return res
+
+    def get_diagnosis(self, name):
+        Evaluation = Pool().get('gnuhealth.patient.evaluation')
+
+        res = None
+        evaluations = Evaluation.search([
+            ('evaluation_date', '=', self.id)
+        ])
+        if evaluations:
+            evaluation = evaluations[0]
+            if evaluation.diagnosis:
+                res = evaluation.diagnosis.id
+        return res
+
+    def get_patient_age(self, name):
+        return self.patient.age
+
+
+class OpenAppointmentReportStart(ModelView):
+    'Open Appointment Report'
+    __name__ = 'gnuhealth.appointment.report.open.start'
+    date = fields.Date('Date', required=True)
+    doctor = fields.Many2One('gnuhealth.physician', 'Doctor', required=True)
+
+    @staticmethod
+    def default_date():
+        return datetime.now()
+
+    @staticmethod
+    def default_doctor():
+        cursor = Transaction().cursor
+        User = Pool().get('res.user')
+        user = User(Transaction().user)
+        login_user_id = int(user.id)
+        cursor.execute('SELECT id FROM party_party WHERE is_doctor=True AND \
+            internal_user = %s LIMIT 1', (login_user_id,))
+        partner_id = cursor.fetchone()
+        if partner_id:
+            cursor = Transaction().cursor
+            cursor.execute('SELECT id FROM gnuhealth_physician WHERE \
+                name = %s LIMIT 1', (partner_id[0],))
+            doctor_id = cursor.fetchone()
+            return int(doctor_id[0])
+
+
+class OpenAppointmentReport(Wizard):
+    'Open Appointment Report'
+    __name__ = 'gnuhealth.appointment.report.open'
+
+    start = StateView('gnuhealth.appointment.report.open.start',
+        'health.appointments_report_open_start_view_form', [
+            Button('Cancel', 'end', 'tryton-cancel'),
+            Button('Open', 'open_', 'tryton-ok', default=True),
+            ])
+    open_ = StateAction('health.act_appointments_report_view_tree')
+
+    def do_open_(self, action):
+        action['pyson_context'] = PYSONEncoder().encode({
+                'date': self.start.date,
+                'doctor': self.start.doctor.id,
+                })
+        return action, {}
+
+    def transition_open_(self):
+        return 'end'
+
+
 # MEDICATION TEMPLATE
 # TEMPLATE USED IN MEDICATION AND PRESCRIPTION ORDERS
 class MedicationTemplate(ModelSQL, ModelView):
@@ -1216,6 +1350,7 @@ class PatientVaccination(ModelSQL, ModelView):
         else:
             return True
 
+
 class PatientPrescriptionOrder(ModelSQL, ModelView):
     'Prescription Order'
     __name__ = 'gnuhealth.prescription.order'
@@ -1236,16 +1371,15 @@ class PatientPrescriptionOrder(ModelSQL, ModelView):
     notes = fields.Text('Prescription Notes')
     pregnancy_warning = fields.Boolean('Pregancy Warning', readonly=True)
     prescription_warning_ack = fields.Boolean('Prescription verified')
+    doctor = fields.Many2One('gnuhealth.physician', 'Prescribing Doctor',
+        readonly=True)
 
-    doctor = fields.Many2One('gnuhealth.physician', 'Prescribing Doctor', readonly=True)
-    
     @classmethod
     def __setup__(cls):
         super(PatientPrescriptionOrder, cls).__setup__()
         cls._constraints += [
             ('check_prescription_warning', 'drug_pregnancy_warning'),
             ('check_health_professional', 'health_professional_warning'),
-
         ]
         cls._error_messages.update({
             'drug_pregnancy_warning':
@@ -1259,7 +1393,6 @@ class PatientPrescriptionOrder(ModelSQL, ModelView):
                     'No health professional associated to this user',
         })
 
-
     def check_health_professional(self):
         return self.doctor
 
@@ -1280,7 +1413,6 @@ class PatientPrescriptionOrder(ModelSQL, ModelView):
 
             return int(doctor_id[0])
 
-
     def check_prescription_warning(self):
         return self.prescription_warning_ack
 
@@ -1323,6 +1455,16 @@ class PatientPrescriptionOrder(ModelSQL, ModelView):
 
         return super(PatientPrescriptionOrder, cls).create(values)
 
+    @classmethod
+    def copy(cls, prescriptions, default=None):
+        if default is None:
+            default = {}
+        default = default.copy()
+        default['prescription_id'] = None
+        default['prescription_date'] = cls.default_prescription_date()
+        return super(PatientPrescriptionOrder, cls).copy(prescriptions,
+            default=default)
+
 
 # PRESCRIPTION LINE
 class PrescriptionLine(ModelSQL, ModelView):
@@ -1448,10 +1590,10 @@ class PatientEvaluation(ModelSQL, ModelView):
     # DEPRECATION NOTE : SIGNS AND SYMPTOMS FIELDS TO BE REMOVED IN 1.6 .
     # NOW WE USE A O2M OBJECT TO MAKE IT MORE SCALABLE, CLEARER AND FUNCTIONAL
     # TO WORK WITH THE CLINICAL FINDINGS OF THE PATIENT
-    loc = fields.Integer('Level of Consciousness',
+    loc = fields.Integer('Glasgow',
         on_change_with=['loc_verbal', 'loc_motor', 'loc_eyes'],
-        help='Level of Consciousness - on Glasgow Coma Scale :  1=coma -'
-        ' 15=normal')
+        help='Level of Consciousness - on Glasgow Coma Scale :  < 9 severe -'
+        ' 9-12 Moderate, > 13 minor')
     loc_eyes = fields.Selection([
         ('1', 'Does not Open Eyes'),
         ('2', 'Opens eyes in response to painful stimuli'),
