@@ -19,94 +19,89 @@
 #
 ##############################################################################
 from datetime import timedelta
-
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.pool import Pool
 
 
+__all__ = ['Physician', 'Appointment']
+
+
 class Physician(ModelSQL, ModelView):
     "Add Calendar to Physician"
-    _name = "gnuhealth.physician"
-    _description = __doc__
+    __name__ = "gnuhealth.physician"
 
     calendar = fields.Many2One('calendar.calendar', 'Calendar')
 
-Physician()
-
 
 class Appointment(ModelSQL, ModelView):
     'Add Calendar to the Appointment'
-    _name = 'gnuhealth.appointment'
-    _description = __doc__
+    __name__ = 'gnuhealth.appointment'
 
     event = fields.Many2One('calendar.event', 'Calendar Event', readonly=True,
         help="Calendar Event")
     appointment_time = fields.Integer('Appointment Time',
         help='Appointment Time (Minutes)')
 
-    def default_appointment_time(self):
+    @staticmethod
+    def default_appointment_time():
         return 30
 
-    def create(self, values):
-        event_obj = Pool().get('calendar.event')
-        patient_obj = Pool().get('gnuhealth.patient')
-        physician_obj = Pool().get('gnuhealth.physician')
+    @classmethod
+    def create(cls, values):
+        Event = Pool().get('calendar.event')
+        Patient = Pool().get('gnuhealth.patient')
+        Physician = Pool().get('gnuhealth.physician')
 
         if values['doctor']:
-            doctor = physician_obj.browse(values['doctor'])
+            doctor = Physician(values['doctor'])
             if doctor.calendar:
-                patient = patient_obj.browse(values['patient'])
-                values['event'] = event_obj.create({
+                patient = Patient(values['patient'])
+                values['event'] = Event.create({
                     'dtstart': values['appointment_date'],
                     'dtend': values['appointment_date'] +
                         timedelta(minutes=values['appointment_time']),
                     'calendar': doctor.calendar.id,
-                    'summary': patient.name.lastname + ', ' + patient.name.name,
+                    'summary': patient.name.lastname + ', ' +
+                        patient.name.name,
                     })
-        return super(Appointment, self).create(values)
+        return super(Appointment, cls).create(values)
 
-    def write(self, ids, values):
-        event_obj = Pool().get('calendar.event')
-        patient_obj = Pool().get('gnuhealth.patient')
-        physician_obj = Pool().get('gnuhealth.physician')
+    @classmethod
+    def write(cls, appointments, values):
+        Event = Pool().get('calendar.event')
+        Patient = Pool().get('gnuhealth.patient')
+        Physician = Pool().get('gnuhealth.physician')
 
-        if isinstance(ids, (int, long)):
-            ids = [ids]
-        for appointment_id in ids:
-            appointment = self.browse(appointment_id)
+        for appointment in appointments:
             if appointment.event:
                 if 'appointment_date' in values:
-                    event_obj.write(appointment.event.id, {
+                    Event.write([appointment.event], {
                         'dtstart': values['appointment_date'],
                         'dtend': values['appointment_date'] +
                             timedelta(minutes=appointment.appointment_time),
                         })
                 if 'appointment_time' in values:
-                    event_obj.write(appointment.event.id, {
+                    Event.write([appointment.event], {
                         'dtend': appointment.appointment_date +
                             timedelta(minutes=values['appointment_time']),
                         })
                 if 'doctor' in values:
-                    doctor = physician_obj.browse(values['doctor'])
-                    event_obj.write(appointment.event.id, {
+                    doctor = Physician(values['doctor'])
+                    Event.write([appointment.event], {
                         'calendar': doctor.calendar.id,
                         })
                 if 'patient' in values:
-                    patient = patient_obj.browse(values['patient'])
-                    event_obj.write(appointment.event.id, {
+                    patient = Patient(values['patient'])
+                    Event.write([appointment.event], {
                         'summary': patient.name.name,
                         })
-        return super(Appointment, self).write(ids, values)
+        return super(Appointment, cls).write(appointments, values)
 
-    def delete(self, ids):
-        event_obj = Pool().get('calendar.event')
+    @classmethod
+    def delete(cls, appointments):
+        Event = Pool().get('calendar.event')
 
-        if isinstance(ids, (int, long)):
-            ids = [ids]
-        for appointment_id in ids:
-            appointment = self.browse(appointment_id)
+        for appointment in appointments:
             if appointment.event:
-                event_obj.delete(appointment.event.id)
-        return super(Appointment, self).delete(ids)
-
-Appointment()
+                Event.delete([appointment.event])
+        return super(Appointment, cls).delete(appointments)
