@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2008-2013  Luis Falcon <lfalcon@gnusolidario.org>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -21,10 +21,13 @@
 from trytond.model import ModelView, ModelSQL, fields
 
 
+__all__ = ['DiseaseGene', 'PatientGeneticRisk', 'FamilyDiseases',
+    'GnuHealthPatient']
+
+
 class DiseaseGene(ModelSQL, ModelView):
     'Disease Genes'
-    _name = 'gnuhealth.disease.gene'
-    _description = __doc__
+    __name__ = 'gnuhealth.disease.gene'
 
     name = fields.Char('Official Symbol', select=True)
     long_name = fields.Char('Official Long Name', select=True)
@@ -39,34 +42,22 @@ class DiseaseGene(ModelSQL, ModelView):
         ], 'Dominance', select=True)
     info = fields.Text('Information', help="Name of the protein(s) affected")
 
-    def get_rec_name(self, ids, name):
-        if not ids:
-            return {}
-        res = {}
-        for gene in self.browse(ids):
-            name = str(gene['name'] + ':' + gene['long_name'])
-            res[gene.id] = name
-        return res
-
-DiseaseGene()
+    def get_rec_name(self, name):
+        return self.name + ':' + self.long_name
 
 
 class PatientGeneticRisk(ModelSQL, ModelView):
     'Patient Genetic Risks'
-    _name = 'gnuhealth.patient.genetic.risk'
-    _description = __doc__
+    __name__ = 'gnuhealth.patient.genetic.risk'
 
     patient = fields.Many2One('gnuhealth.patient', 'Patient', select=True)
     disease_gene = fields.Many2One('gnuhealth.disease.gene',
         'Disease Gene', required=True)
 
-PatientGeneticRisk()
-
 
 class FamilyDiseases(ModelSQL, ModelView):
     'Family Diseases'
-    _name = 'gnuhealth.patient.family.diseases'
-    _description = __doc__
+    __name__ = 'gnuhealth.patient.family.diseases'
 
     patient = fields.Many2One('gnuhealth.patient', 'Patient', select=True)
     name = fields.Many2One('gnuhealth.pathology', 'Disease', required=True)
@@ -88,22 +79,17 @@ class FamilyDiseases(ModelSQL, ModelView):
         ('grandmother', 'Grandmother'),
         ('cousin', 'Cousin'),
         ], 'Relative',
-        help="First degree = siblings, mother and father; second degree = " \
+        help="First degree = siblings, mother and father; second degree = "
         "Uncles, nephews and Nieces; third degree = Grandparents and cousins",
         required=True)
 
-FamilyDiseases()
-
 
 class GnuHealthPatient (ModelSQL, ModelView):
     'Add to the Medical patient_data class (gnuhealth.patient) the genetic ' \
     'and family risks'
-    _name = 'gnuhealth.patient'
-    _description = __doc__
+    __name__ = 'gnuhealth.patient'
 
     genetic_risks = fields.One2Many('gnuhealth.patient.genetic.risk',
         'patient', 'Genetic Risks')
     family_history = fields.One2Many('gnuhealth.patient.family.diseases',
         'patient', 'Family History')
-
-GnuHealthPatient()
