@@ -26,7 +26,7 @@ from trytond.pyson import Eval, Not, Bool, And, Equal
 
 
 __all__ = ['InpatientSequences', 'DietTherapeutic', 'DietBelief',
-    'InpatientRegistration', 'Appointment', 'PatientData',
+    'InpatientRegistration','BedTransfer', 'Appointment', 'PatientData',
     'InpatientMedication', 'InpatientMedicationAdminTimes',
     'InpatientMedicationLog', 'InpatientDiet']
 
@@ -103,7 +103,12 @@ class InpatientRegistration(ModelSQL, ModelView):
     admission_reason = fields.Many2One('gnuhealth.pathology',
         'Reason for Admission', help="Reason for Admission", select=True)
     bed = fields.Many2One('gnuhealth.hospital.bed', 'Hospital Bed',
-        required=True, select=True)
+        states={
+            'required': Not(Bool(Eval('name'))),
+            'readonly': Bool(Eval('name')),
+            },
+        depends=['name'],
+)
     nursing_plan = fields.Text('Nursing Plan')
     medications = fields.One2Many('gnuhealth.inpatient.medication', 'name',
         'Medications')
@@ -130,6 +135,10 @@ class InpatientRegistration(ModelSQL, ModelView):
         ('hospitalized', 'hospitalized'),
         ), 'Status', select=True)
 
+    
+    bed_transfers = fields.One2Many('gnuhealth.bed.transfer', 'name',
+        'Transfer History', readonly=True)
+
     @classmethod
     def __setup__(cls):
         super(InpatientRegistration, cls).__setup__()
@@ -138,7 +147,8 @@ class InpatientRegistration(ModelSQL, ModelView):
              'The Registration code already exists')
         ]
         cls._error_messages.update({
-                'bed_is_not_available': 'Bed is not available'})
+                'bed_is_not_available': 'Bed is not available',
+                'destination_bed_unavailable': 'Destination bed unavailable'})
         cls._buttons.update({
                 'confirmed': {
                     'invisible': And(Not(Equal(Eval('state'), 'free')),
@@ -155,6 +165,7 @@ class InpatientRegistration(ModelSQL, ModelView):
                     },
                 })
 
+
     ## Method to check for availability and make the hospital bed reservation
 
     @classmethod
@@ -215,6 +226,7 @@ class InpatientRegistration(ModelSQL, ModelView):
             cls.write(registrations, {'state': 'hospitalized'})
             Bed.write([registration_id.bed], {'state': 'occupied'})
 
+ 
     @classmethod
     def create(cls, values):
         Sequence = Pool().get('ir.sequence')
@@ -231,6 +243,41 @@ class InpatientRegistration(ModelSQL, ModelView):
     def default_state():
         return 'free'
 
+    
+    # Allow searching by the hospitalization code or patient name
+    
+    def get_rec_name(self, name):
+        if self.patient:
+            return self.name + ': ' + self.patient.name.name + ' ' + \
+             self.patient.name.lastname
+        else:
+            return self.name
+
+    
+    @classmethod
+    def search_rec_name(cls, name, clause):
+        field = None
+        for field in ('name', 'patient'):
+            registrations = cls.search([(field,) + clause[1:]], limit=1)
+            if registrations:
+                break
+        if registrations:
+            return [(field,) + clause[1:]]
+        return [(cls._rec_name,) + clause[1:]]
+
+
+class BedTransfer(ModelSQL, ModelView):
+    'Bed transfers'
+    __name__ = 'gnuhealth.bed.transfer'
+
+    name = fields.Many2One('gnuhealth.inpatient.registration',
+        'Registration Code')
+    transfer_date = fields.DateTime('Date')
+    bed_from = fields.Many2One('gnuhealth.hospital.bed', 'From',
+        )
+    bed_to = fields.Many2One('gnuhealth.hospital.bed', 'To',
+        )
+    reason = fields.Char('Reason')
 
 class Appointment(ModelSQL, ModelView):
     'Add Inpatient Registration field to the Appointment model.'
