@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-#    Copyright (C) 2011-2012 Sebastián Marró
+#    Copyright (C) 2011 Cédric Krier
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -15,13 +15,25 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import re
 from setuptools import setup
+import re
+import os
+import ConfigParser
 
-info = eval(open('__tryton__.py').read())
+def read(fname):
+    return open(os.path.join(os.path.dirname(__file__), fname)).read()
+
+config = ConfigParser.ConfigParser()
+config.readfp(open('tryton.cfg'))
+info = dict(config.items('tryton'))
+
+for key in ('depends', 'extras_depend', 'xml'):
+    if key in info:
+        info[key] = info[key].strip().splitlines()
 major_version, minor_version = 2, 6
 
 requires = []
+
 for dep in info.get('depends', []):
     if dep.startswith('health'):
         requires.append('trytond_%s == %s' %
@@ -35,19 +47,22 @@ requires.append('trytond >= %s.%s, < %s.%s' %
 
 setup(name='trytond_health_inpatient_calendar',
     version=info.get('version', '0.0.1'),
-    description=info.get('description', ''),
-    author=info.get('author', ''),
-    author_email=info.get('email', ''),
-    url=info.get('website', ''),
+    description=info.get('description', 'GNU Health Inpatient calendar Module'),
+    author=info.get('author', 'GNU Solidario'),
+    author_email=info.get('email', 'health@gnusolidario.org'),
+    url=info.get('website', 'http://health.gnu.org/'),
     download_url='http://ftp.gnu.org/gnu/health/',
     package_dir={'trytond.modules.health_inpatient_calendar': '.'},
     packages=[
         'trytond.modules.health_inpatient_calendar',
+        'trytond.modules.health_inpatient_calendar.tests',
         ],
     package_data={
         'trytond.modules.health_inpatient_calendar': info.get('xml', []) \
-            + info.get('translation', []),
+            + info.get('translation', []) \
+            + ['tryton.cfg', 'doc/*.rst', 'locale/*.po', 'report/*.odt', 'icons/*.svg'],
         },
+
     classifiers=[
         'Development Status :: 5 - Production/Stable',
         'Environment :: Plugins',
@@ -70,4 +85,6 @@ setup(name='trytond_health_inpatient_calendar',
     [trytond.modules]
     health_inpatient_calendar = trytond.modules.health_inpatient_calendar
     """,
+    test_suite='tests',
+    test_loader='trytond.test_loader:Loader',
     )
