@@ -15,13 +15,25 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import re
 from setuptools import setup
+import re
+import os
+import ConfigParser
 
-info = eval(open('__tryton__.py').read())
+def read(fname):
+    return open(os.path.join(os.path.dirname(__file__), fname)).read()
+
+config = ConfigParser.ConfigParser()
+config.readfp(open('tryton.cfg'))
+info = dict(config.items('tryton'))
+
+for key in ('depends', 'extras_depend', 'xml'):
+    if key in info:
+        info[key] = info[key].strip().splitlines()
 major_version, minor_version = 2, 6
 
 requires = []
+
 for dep in info.get('depends', []):
     if dep.startswith('health'):
         requires.append('trytond_%s == %s' %
@@ -35,10 +47,10 @@ requires.append('trytond >= %s.%s, < %s.%s' %
 
 setup(name='trytond_health_nursing',
     version=info.get('version', '0.0.1'),
-    description=info.get('description', ''),
-    author=info.get('author', ''),
-    author_email=info.get('email', ''),
-    url=info.get('website', ''),
+    description=info.get('description', 'GNU Health Nursing Module'),
+    author=info.get('author', 'GNU Solidario'),
+    author_email=info.get('email', 'health@gnusolidario.org'),
+    url=info.get('website', 'http://health.gnu.org/'),
     download_url='http://ftp.gnu.org/gnu/health/',
     package_dir={'trytond.modules.health_nursing': '.'},
     packages=[
@@ -48,8 +60,9 @@ setup(name='trytond_health_nursing',
     package_data={
         'trytond.modules.health_nursing': info.get('xml', []) \
             + info.get('translation', []) \
-            + ['report/*.odt', 'icons/*.svg'],
+            + ['tryton.cfg', 'doc/*.rst', 'locale/*.po', 'report/*.odt', 'icons/*.svg'],
         },
+
     classifiers=[
         'Development Status :: 5 - Production/Stable',
         'Environment :: Plugins',
