@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2008-2013  Luis Falcon <lfalcon@gnusolidario.org>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -19,4 +19,10 @@
 #
 ##############################################################################
 
-from health_socioeconomics import *
+from trytond.pool import Pool
+from .health_socioeconomics import *
+
+def register():
+    Pool.register(
+        MedicalPatient,
+        module='health_socioeconomics', type_='model')
