@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2008-2013  Luis Falcon <lfalcon@gnusolidario.org>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -20,10 +20,10 @@
 ##############################################################################
 from trytond.model import ModelView, ModelSQL, fields
 
+__all__ = ['MedicalPatient']
 
 class MedicalPatient(ModelSQL, ModelView):
-    _name = 'gnuhealth.patient'
-    _description = __doc__
+    __name__ = 'gnuhealth.patient'
 
     ses = fields.Selection([
         ('0', 'Lower'),
@@ -136,37 +136,42 @@ class MedicalPatient(ModelSQL, ModelView):
     hours_outside = fields.Integer('Hours outside home',
         help="Number of hours a day the patient spend outside the house")
 
-    def default_sewers(self):
+    @staticmethod
+    def default_sewers():
         return True
 
-    def default_water(self):
+    @staticmethod
+    def default_water():
         return True
 
-    def defaul_trash(self):
+    @staticmethod
+    def default_trash():
         return True
 
-    def default_electricity(self):
+    @staticmethod
+    def default_electricity():
         return True
 
-    def default_gas(self):
+    @staticmethod
+    def default_gas():
         return True
 
-    def default_telephone(self):
+    @staticmethod
+    def default_telephone():
         return True
 
-    def default_television(self):
+    @staticmethod
+    def default_television():
         return True
 
-    def on_change_with_fam_apgar_score(self, vals):
-        fam_apgar_help = int(vals.get('fam_apgar_help'))
-        fam_apgar_timesharing = int(vals.get('fam_apgar_timesharing') or '0')
-        fam_apgar_discussion = int(vals.get('fam_apgar_discussion') or '0')
-        fam_apgar_decisions = int(vals.get('fam_apgar_decisions') or '0')
-        fam_apgar_affection = int(vals.get('fam_apgar_affection') or '0')
+    def on_change_with_fam_apgar_score(self):
+        fam_apgar_help = int(self.fam_apgar_help)
+        fam_apgar_timesharing = int(self.fam_apgar_timesharing or '0')
+        fam_apgar_discussion = int(self.fam_apgar_discussion or '0')
+        fam_apgar_decisions = int(self.fam_apgar_decisions or '0')
+        fam_apgar_affection = int(self.fam_apgar_affection or '0')
         total = (fam_apgar_help + fam_apgar_timesharing +
             fam_apgar_discussion + fam_apgar_decisions +
             fam_apgar_affection)
 
         return total
-
-MedicalPatient()
